"""
quillmark - Python bindings for Quillmark template rendering engine.

This is currently a stub package reserved on PyPI.
The implementation is under development.
"""

try:
    from quillmark._core import __version__
except ImportError:
    __version__ = "0.1.0"

__all__ = ["__version__"]
